"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const readPackageJson_1 = require("../../tools/readPackageJson");
const es_1 = require("fs-i/es");
const fs_1 = require("fs");
const util_1 = require("../../common/util");
const asyncExec_1 = require("../../tools/asyncExec");
const typedoc_format_1 = require("typedoc-format");
const log_1 = require("../../common/log");
class NodeBuilder {
    run(projectPath, projectConfig) {
        return __awaiter(this, void 0, void 0, function* () {
            log_1.printMessage("正在将TypeScript编译成JavaScript...");
            yield asyncExec_1.asyncExec("tsc", ["-p", projectPath]);
            let packageJson = yield readPackageJson_1.readPackageJson(path.join(projectPath, "package.json"));
            if (projectConfig.command) {
                yield this.addCommand(projectPath, packageJson.name, projectConfig);
            }
            if (projectConfig.documents) {
                yield this.buildDocs(projectPath);
            }
        });
    }
    addCommand(projectPath, projectName, projectConfig) {
        return __awaiter(this, void 0, void 0, function* () {
            log_1.printMessage("正在将程序处理成命令行...");
            yield util_1.editPackageJson(projectPath, json => {
                if (typeof projectConfig.command === "boolean") {
                    Object.assign(json, {
                        bin: {
                            [projectName]: `./es/bin/${projectName}`
                        }
                    });
                }
                else if (typeof projectConfig.command === "string") {
                    Object.assign(json, {
                        bin: {
                            [projectConfig.command]: `./es/bin/${projectName}`
                        }
                    });
                }
                else if (projectConfig.command instanceof Array) {
                    let binNode = {};
                    projectConfig.command.map(c => {
                        binNode[c] = `./es/bin/${projectName}`;
                    });
                    Object.assign(json, {
                        bin: binNode
                    });
                }
            });
            let binPath = path.join(projectPath, "es", "bin");
            yield es_1.mkdirs(binPath);
            fs_1.writeFileSync(path.join(binPath, `${projectName}`), `
#!/usr/bin/env node
module.exports = require('../');
      `.trim());
            fs_1.writeFileSync(path.join(binPath, `${projectName}.cmd`), `
@IF EXIST "%~dp0\\node.exe" (
  "%~dp0\\node.exe"  "%~dp0\\..\\${projectName}\\bin\\${projectName}" %*
) ELSE (
  @SETLOCAL
  @SET PATHEXT=%PATHEXT:;.JS;=;%
  node  "%~dp0\\..\\${projectName}\\bin\\${projectName}" %*
)
      `.trim());
        });
    }
    buildDocs(projectPath) {
        return __awaiter(this, void 0, void 0, function* () {
            log_1.printMessage("正在生成文档...");
            let docs = path.join(projectPath, "docs");
            let src = path.join(projectPath, "src");
            let typedoc = path.join(util_1.getCreateProjectPath(), "node_modules", "typedoc", "bin", "typedoc");
            yield asyncExec_1.asyncExec(typedoc, ["--out", docs, src, "--module", "commonjs", "--hideGenerator"]);
            yield typedoc_format_1.format(docs);
        });
    }
}
exports.NodeBuilder = NodeBuilder;
//# sourceMappingURL=nodeBuilder.js.map