"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const baseProj_1 = require("./baseProj");
const fs_i_1 = require("fs-i");
const path = require("path");
const globalData_1 = require("../../../model/globalData");
const ProjectType_1 = require("../../../model/ProjectType");
const angularProj_1 = require("./angularProj");
const webpackProj_1 = require("./webpackProj");
const nodeProj_1 = require("./nodeProj");
const util_1 = require("../../../common/util");
class MainProj extends baseProj_1.BaseProj {
    getQuestions() {
        let questionList = [
            {
                name: "projectName",
                type: "input",
                message: "请输入项目名称",
                default: "project1"
            },
            {
                name: "projectType",
                type: "list",
                message: "请选择项目类型",
                default: "node",
                choices: ["node", "webpack", "angular"]
            }
        ];
        return questionList;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            let answer = yield this.getAnswers();
            globalData_1.GlobalData.projectName = answer.projectName;
            globalData_1.GlobalData.projectType = ProjectType_1.newProjectType(answer.projectType);
            globalData_1.GlobalData.projectRootPath = path.join(process.cwd(), answer.projectName);
            yield fs_i_1.mkdirs(globalData_1.GlobalData.projectRootPath);
            let nodeProj = new nodeProj_1.NodeProj();
            let angularProj = new angularProj_1.AngularProj();
            let webpackProj = new webpackProj_1.WebpackProj();
            switch (globalData_1.GlobalData.projectType) {
                case ProjectType_1.ProjectType.node:
                    yield nodeProj.run();
                    break;
                case ProjectType_1.ProjectType.webpack:
                    yield webpackProj.run();
                    break;
                case ProjectType_1.ProjectType.angular:
                    yield angularProj.run();
                    break;
            }
            yield this.replaceProjectName();
        });
    }
    replaceProjectName() {
        return __awaiter(this, void 0, void 0, function* () {
            let files = yield fs_i_1.getAllFiles(globalData_1.GlobalData.projectRootPath);
            for (let file of files) {
                yield util_1.editFile(file, fileContent => {
                    return fileContent.replace(/{{projectName}}/g, globalData_1.GlobalData.projectName);
                });
            }
        });
    }
}
exports.MainProj = MainProj;
//# sourceMappingURL=mainProj.js.map